package fsmNetworkExample;

/**
 * 
 * The interface FSM defines that a finite state machine
 * (seen as a black box from outside)
 * should provide just three methods.
 * For simplicity, a FSM accepts just int inputs
 * and outputs just String Moore values (generated in a state)
 * and int Mealy values (generated after input)
 * 
 * int push(int input)
 *    feeds input to the FSM
 *    returns current Mealy output  
 *
 * int getStateOutput()
 *    returns current Moore (state) output
 *    
 * reset()
 *   Resets all internal variables of the FSM so that it is 
 *   in the initial state again.
 *   In fact, this is a shortcut: every FSM should accept RESET input
 *   and return it to the initial state, so instead of calling
 *     fsm.push(RESET)
 *   we just call 
 *     fsm.reset()  
 *
 * It is up to implemenatation to decide if the FSM is a pure Moore/Mealy FSM,
 * if it is an acceptor / recognizer / transducer / ...
 */
public interface FSM {
	int push(int input);
	String getStateOutput();
	void reset();
}
