package fsmNetworkExample;

/**
 * Example use of the finite state machine FSMClock.
 * A fsm fsmClock is created.
 * Two signals are fed to its input: 
 *  CLK_PULSE - automatically, once per second
 *  RESET - on user request from keyboard
 *
 * After every input, the output is displayed through console output.
 * Two digit "seconds" indicator is output every second (from 00 to 59).
 *  
 * The code is kept as simple as possible to show just FSM functionality.
 * Making complex FSMs, networks of FSMs, GUI, etc. is left as an exercise.
 * 
 */

import java.util.Scanner;
import java.util.Timer;
import java.util.TimerTask;

public class FSMClockTest {

	static FSMClock fsmClock;
	private static Scanner s;

	public static void main(String[] args) {
		fsmClock = new FSMClock();

		System.out.println("Example implementation of finite state machines network:");
		System.out.println("Simple clock with just 'seconds' indicator.");
		System.out.println("Press r+ENTER to reset, q+ENTER to quit.");

		/*
		 * Once per second, feed fsmClock with CLK_PULSE signal
		 * and display current fsmClock Moore output.
		 */
		Timer clockGen = new Timer();
		clockGen.schedule(new TimerTask() {
			@Override
			public void run() {
				fsmClock.push(FSMClock.IN_CLK_PULSE);
				System.out.println(" --- " + fsmClock.getStateOutput());
			}
		}, 0, 1000);
		
		
		/*
		 * User input processing
		 */
		s = new Scanner(System.in);
		String input;
		while (true) {
			input = s.nextLine();
			if (input.equals("q")) {
				break;
			} else if (input.equals("r")) {
				fsmClock.push(FSMClock.IN_RESET);
				System.out.println(" --- " + fsmClock.getStateOutput());
			}
		}

		/*
		 * Stop the timer
		 */
		clockGen.cancel();
	}

}
